@@ -1,12 +1,22 @@
 # -*- coding: utf-8 -*-
 from abc import ABCMeta, abstractmethod
+from typing import Any, Dict, List, MutableMapping, Tuple
+from enos.provider.host import Host
+
+
+# XXX: We define Networks and Roles here explicitly, because importing
+# enoslib.type takes 2 seconds.
+Networks = List[Dict[Any, Any]]
+Roles = MutableMapping[str, List[Host]]
 
 
 class Provider:
     __metaclass__ = ABCMeta
 
     @abstractmethod
-    def init(self, config, force=False):
+    def init(self,
+             config: Dict[str, Any],
+             force: bool = False) -> Tuple[Roles, Networks]:
         """Provides resources and provisions the environment.
 
         The `config` parameter contains the client request (eg, number
@@ -27,7 +37,7 @@ class Provider:
         pass
 
     @abstractmethod
-    def default_config(self):
+    def default_config(self) -> Dict[str, Any]:
         """The default provider configuration.
 
         Returns a dict with all keys used to initialise the provider
